package cn.com.poc.knowledge;

import cn.com.poc.knowledge.aggregate.KnowledgeService;
import cn.com.yict.framemax.core.spring.SingleContextInitializer;
import com.vladsch.flexmark.html.HtmlRenderer;
import com.vladsch.flexmark.parser.Parser;
import com.vladsch.flexmark.util.ast.Document;
import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
import org.apache.poi.poifs.filesystem.DirectoryEntry;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.MockitoAnnotations;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.web.WebAppConfiguration;

import javax.annotation.Resource;
import java.io.ByteArrayInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;

/**
 * @author alex.yao
 * @date 2025/2/6
 */
@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(initializers = SingleContextInitializer.class)
@WebAppConfiguration
public class KnowledgeServiceTest {

    @Resource
    private KnowledgeService knowledgeService;

    @Before
    public void setUp() {
        MockitoAnnotations.initMocks(this);
    }


    @Test
    public void test_delDocument() {
        knowledgeService.delDocument(138, 1071);
    }


    //    @Test
    public static void main(String[] args) throws IOException, InvalidFormatException {
        String markdownContent = readMarkdownFile("C:\\Users\\52747\\Desktop\\1.md");
        String htmlContent = convertMarkdownToHtml(markdownContent);
        convertHtmlToWord(htmlContent, "C:\\Users\\52747\\Desktop\\1.docx");
    }

    private static String readMarkdownFile(String filePath) {
        try {
            return new String(Files.readAllBytes(Paths.get(filePath)));
        } catch (IOException e) {
            e.printStackTrace();
            return "";
        }
    }

    private static String convertMarkdownToHtml(String markdown) {
        Parser parser = Parser.builder().build();
        HtmlRenderer renderer = HtmlRenderer.builder().build();
        Document document = parser.parse(markdown);
        return renderer.render(document);
    }

    private static void convertHtmlToWord(String html, String outputPath) throws IOException {
        FileOutputStream outputStream = new FileOutputStream(outputPath);
        ByteArrayInputStream bais = new ByteArrayInputStream(html.getBytes());//将字节数组包装到流中
        POIFSFileSystem poifs = new POIFSFileSystem();
        DirectoryEntry directory = poifs.getRoot();
        directory.createDocument("WordDocument", bais);
        poifs.writeFilesystem(outputStream);
    }
}
